#ifndef EFL_UI_SCROLLABLE_INTERACTIVE_IMPL_HH
#define EFL_UI_SCROLLABLE_INTERACTIVE_IMPL_HH

#include "efl_ui_scrollable_interactive.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<Eina_Position2D>::type Scrollable_Interactive::content_pos_get() const
{
   Eina_Position2D __return_value =  ::efl_ui_scrollable_content_pos_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Position2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::content_pos_set( ::efl::eolian::in_traits<Eina_Position2D>::type pos) const
{
    ::efl_ui_scrollable_content_pos_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Position2D,  ::efl::eolian::in_traits<Eina_Position2D>::type>(pos));
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type Scrollable_Interactive::content_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_scrollable_content_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Eina_Rect>::type Scrollable_Interactive::viewport_geometry_get() const
{
   Eina_Rect __return_value =  ::efl_ui_scrollable_viewport_geometry_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Rect>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::bounce_enabled_get( ::efl::eolian::out_traits<bool>::type horiz,  ::efl::eolian::out_traits<bool>::type vert) const
{
   Eina_Bool __out_param_horiz = {};
   Eina_Bool __out_param_vert = {};
    ::efl_ui_scrollable_bounce_enabled_get(_eo_ptr()
      , & __out_param_horiz
      , & __out_param_vert);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(horiz, __out_param_horiz);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(vert, __out_param_vert);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::bounce_enabled_set( ::efl::eolian::in_traits<bool>::type horiz,  ::efl::eolian::in_traits<bool>::type vert) const
{
    ::efl_ui_scrollable_bounce_enabled_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(horiz)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(vert));
}
inline ::efl::eolian::return_traits<bool>::type Scrollable_Interactive::scroll_freeze_get() const
{
   Eina_Bool __return_value =  ::efl_ui_scrollable_scroll_freeze_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::scroll_freeze_set( ::efl::eolian::in_traits<bool>::type freeze) const
{
    ::efl_ui_scrollable_scroll_freeze_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(freeze));
}
inline ::efl::eolian::return_traits<bool>::type Scrollable_Interactive::scroll_hold_get() const
{
   Eina_Bool __return_value =  ::efl_ui_scrollable_scroll_hold_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::scroll_hold_set( ::efl::eolian::in_traits<bool>::type hold) const
{
    ::efl_ui_scrollable_scroll_hold_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(hold));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::looping_get( ::efl::eolian::out_traits<bool>::type loop_h,  ::efl::eolian::out_traits<bool>::type loop_v) const
{
   Eina_Bool __out_param_loop_h = {};
   Eina_Bool __out_param_loop_v = {};
    ::efl_ui_scrollable_looping_get(_eo_ptr()
      , & __out_param_loop_h
      , & __out_param_loop_v);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(loop_h, __out_param_loop_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(loop_v, __out_param_loop_v);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::looping_set( ::efl::eolian::in_traits<bool>::type loop_h,  ::efl::eolian::in_traits<bool>::type loop_v) const
{
    ::efl_ui_scrollable_looping_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(loop_h)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(loop_v));
}
inline ::efl::eolian::return_traits<Efl_Ui_Scroll_Block>::type Scrollable_Interactive::movement_block_get() const
{
   Efl_Ui_Scroll_Block __return_value =  ::efl_ui_scrollable_movement_block_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Scroll_Block>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::movement_block_set( ::efl::eolian::in_traits<Efl_Ui_Scroll_Block>::type block) const
{
    ::efl_ui_scrollable_movement_block_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Scroll_Block,  ::efl::eolian::in_traits<Efl_Ui_Scroll_Block>::type>(block));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::gravity_get( ::efl::eolian::out_traits<double>::type x,  ::efl::eolian::out_traits<double>::type y) const
{
   double __out_param_x = {};
   double __out_param_y = {};
    ::efl_ui_scrollable_gravity_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::gravity_set( ::efl::eolian::in_traits<double>::type x,  ::efl::eolian::in_traits<double>::type y) const
{
    ::efl_ui_scrollable_gravity_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::match_content_set( ::efl::eolian::in_traits<bool>::type w,  ::efl::eolian::in_traits<bool>::type h) const
{
    ::efl_ui_scrollable_match_content_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(w)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(h));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::scroll( ::efl::eolian::in_traits<Eina_Rect>::type rect,  ::efl::eolian::in_traits<bool>::type animation) const
{
    ::efl_ui_scrollable_scroll(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Rect,  ::efl::eolian::in_traits<Eina_Rect>::type>(rect)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(animation));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<Eina_Position2D>::type Scrollable_Interactive::content_pos_get() const
{
   Eina_Position2D __return_value =  ::efl_ui_scrollable_content_pos_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Position2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::content_pos_set( ::efl::eolian::in_traits<Eina_Position2D>::type pos) const
{
    ::efl_ui_scrollable_content_pos_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Position2D,  ::efl::eolian::in_traits<Eina_Position2D>::type>(pos));
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type Scrollable_Interactive::content_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_scrollable_content_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Eina_Rect>::type Scrollable_Interactive::viewport_geometry_get() const
{
   Eina_Rect __return_value =  ::efl_ui_scrollable_viewport_geometry_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Rect>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::bounce_enabled_get( ::efl::eolian::out_traits<bool>::type horiz,  ::efl::eolian::out_traits<bool>::type vert) const
{
   Eina_Bool __out_param_horiz = {};
   Eina_Bool __out_param_vert = {};
    ::efl_ui_scrollable_bounce_enabled_get(_eo_ptr()
      , & __out_param_horiz
      , & __out_param_vert);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(horiz, __out_param_horiz);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(vert, __out_param_vert);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::bounce_enabled_set( ::efl::eolian::in_traits<bool>::type horiz,  ::efl::eolian::in_traits<bool>::type vert) const
{
    ::efl_ui_scrollable_bounce_enabled_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(horiz)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(vert));
}
inline ::efl::eolian::return_traits<bool>::type Scrollable_Interactive::scroll_freeze_get() const
{
   Eina_Bool __return_value =  ::efl_ui_scrollable_scroll_freeze_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::scroll_freeze_set( ::efl::eolian::in_traits<bool>::type freeze) const
{
    ::efl_ui_scrollable_scroll_freeze_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(freeze));
}
inline ::efl::eolian::return_traits<bool>::type Scrollable_Interactive::scroll_hold_get() const
{
   Eina_Bool __return_value =  ::efl_ui_scrollable_scroll_hold_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::scroll_hold_set( ::efl::eolian::in_traits<bool>::type hold) const
{
    ::efl_ui_scrollable_scroll_hold_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(hold));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::looping_get( ::efl::eolian::out_traits<bool>::type loop_h,  ::efl::eolian::out_traits<bool>::type loop_v) const
{
   Eina_Bool __out_param_loop_h = {};
   Eina_Bool __out_param_loop_v = {};
    ::efl_ui_scrollable_looping_get(_eo_ptr()
      , & __out_param_loop_h
      , & __out_param_loop_v);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(loop_h, __out_param_loop_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(loop_v, __out_param_loop_v);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::looping_set( ::efl::eolian::in_traits<bool>::type loop_h,  ::efl::eolian::in_traits<bool>::type loop_v) const
{
    ::efl_ui_scrollable_looping_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(loop_h)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(loop_v));
}
inline ::efl::eolian::return_traits<Efl_Ui_Scroll_Block>::type Scrollable_Interactive::movement_block_get() const
{
   Efl_Ui_Scroll_Block __return_value =  ::efl_ui_scrollable_movement_block_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Scroll_Block>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::movement_block_set( ::efl::eolian::in_traits<Efl_Ui_Scroll_Block>::type block) const
{
    ::efl_ui_scrollable_movement_block_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Scroll_Block,  ::efl::eolian::in_traits<Efl_Ui_Scroll_Block>::type>(block));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::gravity_get( ::efl::eolian::out_traits<double>::type x,  ::efl::eolian::out_traits<double>::type y) const
{
   double __out_param_x = {};
   double __out_param_y = {};
    ::efl_ui_scrollable_gravity_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::gravity_set( ::efl::eolian::in_traits<double>::type x,  ::efl::eolian::in_traits<double>::type y) const
{
    ::efl_ui_scrollable_gravity_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::match_content_set( ::efl::eolian::in_traits<bool>::type w,  ::efl::eolian::in_traits<bool>::type h) const
{
    ::efl_ui_scrollable_match_content_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(w)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(h));
}
inline ::efl::eolian::return_traits<void>::type Scrollable_Interactive::scroll( ::efl::eolian::in_traits<Eina_Rect>::type rect,  ::efl::eolian::in_traits<bool>::type animation) const
{
    ::efl_ui_scrollable_scroll(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Rect,  ::efl::eolian::in_traits<Eina_Rect>::type>(rect)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(animation));
}
inline efl::ui::Scrollable_Interactive::operator ::efl::ui::Scrollable_Interactive() const { return *static_cast< ::efl::ui::Scrollable_Interactive const*>(static_cast<void const*>(this)); }
inline efl::ui::Scrollable_Interactive::operator ::efl::ui::Scrollable_Interactive&() { return *static_cast< ::efl::ui::Scrollable_Interactive*>(static_cast<void*>(this)); }
inline efl::ui::Scrollable_Interactive::operator ::efl::ui::Scrollable_Interactive const&() const { return *static_cast< ::efl::ui::Scrollable_Interactive const*>(static_cast<void const*>(this)); }
} } }
#endif
